@@ -5,9 +5,7 @@ from contract_nli.model.decomposable_attention import DecomposableAttention
 from sklearn.metrics import classification_report
 
 class Predict():
-    def __init__(self, embed_size, num_hiddens,
-                  model_path="contract_nli/trained_model/model.pth",
-                  vocab_path="contract_nli/trained_model/vocab.pth"):
+    def __init__(self, embed_size, num_hiddens,model_path,vocab_path):
       self.embed_size = embed_size
       self.num_hiddens = num_hiddens
       self.device = torch.device('cuda' if torch.cuda.is_available() else 'cpu')
